#!/usr/bin/python3
import os
import tkinter as tk
from tkinter import ttk

from wg_func import TunnelActiv, ListTunnels, ImportTunnel, ExportTunnels


class MainWindow(tk.Tk):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.switch_on = None
        self.switch_off = None
        self.x_width = 600
        self.y_height = 350
        self.monitor_center_x = self.winfo_screenwidth() / 2 - (self.x_width / 2)
        self.monitor_center_y = self.winfo_screenheight() / 2 - (self.y_height / 2)
        self.resizable(width=False, height=False)
        self.lb_tunnel = None
        self.title('Wire-Py')
        self.configure()
        self.geometry('%dx%d+%d+%d' % (self.x_width, self.y_height, self.monitor_center_x, self.monitor_center_y))
        # Load the image file from disk.
        self.wg_icon = tk.PhotoImage(file=r'icons/wg-vpn-48.png')
        # Set it as the window icon.
        self.iconphoto(True, self.wg_icon)

        FrameWidgets(self).grid()


class FrameWidgets(ttk.Frame):
    def __init__(self, container, **kwargs):
        super().__init__(container, **kwargs)

        self.wg_vpn_start = tk.PhotoImage(file=r'icons/wg-vpn-start-48.png')
        self.wg_vpn_stop = tk.PhotoImage(file=r'icons/wg-vpn-stop-48.png')
        self.wgi_on = tk.PhotoImage(file=r'icons/wire-switch-on-48.png')
        self.wgi_off = tk.PhotoImage(file=r'icons/wire-switch-off-48.png')
        self.imp_pic = tk.PhotoImage(file=r'icons/wg-import.png')
        self.tr_pic = tk.PhotoImage(file=r'icons/wg-trash-48.png')
        self.exp_pic = tk.PhotoImage(file=r'icons/wg-export-48.png')
        self.warning_pic = tk.PhotoImage(file=r'icons/warning_64.png')

        # Show active Tunnel
        self.a = TunnelActiv.active()

        # Show active Label
        self.select_tunnel = None
        self.lb = tk.Label(self, text='Active:')
        self.lb.config(font=("Ubuntu", 11, "bold"))
        self.lb.grid(column=2, row=1, padx=10, pady=5, sticky="e")

        # Label to Show active Tunnel
        self.StrVar = tk.StringVar(value=self.a)
        self.lb_tunnel = tk.Label(self, textvariable=self.StrVar, fg='green')

        self.lb_tunnel.config(font=("Ubuntu", 11, "bold"))
        self.lb_tunnel.grid(column=3, row=1, sticky="w")

        self.scrollbar = tk.Scrollbar(self)
        self.l_box = tk.Listbox(self, fg='#606060', selectmode='single')
        self.l_box.config(highlightthickness=0, relief='flat')
        self.scrollbar.config(command=self.l_box.yview)
        self.l_box.config(font=("Ubuntu", 12, "bold"))
        self.l_box.grid(column=1, rowspan=3, row=1, )

        self.tl = ListTunnels.tl_list()
        for tunnels in self.tl:
            self.l_box.insert("end", tunnels)
            self.l_box.update()
            self.l_box.select_set(0)  # Later add, for first Item Auto select
        # Button Vpn
        if self.a != '':
            self.btn_stst = tk.Button(self, image=self.wg_vpn_stop, bd=0, command=self.wg_switch)
            self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
        else:
            self.btn_stst = tk.Button(self, image=self.wg_vpn_start, bd=0, command=self.wg_switch)
            self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
        # Button Import
        self.btn_i = tk.Button(self, image=self.imp_pic, bd=0, command=lambda: ImportTunnel.wg_import_select(self))
        self.btn_i.grid(column=0, row=2, padx=15, pady=15)

        def delete():
            self.select_tunnel = self.l_box.curselection()
            select_tl = self.l_box.get(self.select_tunnel[0])
            os.system('nmcli connection delete ' + str(select_tl))
            self.l_box.delete(self.select_tunnel[0])
            if self.a != '':
                self.StrVar.set(value='')
                self.btn_stst = tk.Button(self, image=self.wg_vpn_start, bd=0, command=self.wg_switch)
                self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
                self.l_box.update()
                self.l_box.select_set(0)

        # Button Trash
        self.btn_tr = tk.Button(self, image=self.tr_pic, bd=0, command=delete)
        self.btn_tr.grid(column=0, row=3, padx=15, pady=15)
        # Button Export
        self.btn_exp = tk.Button(self, image=self.exp_pic, bd=0)
        self.btn_exp.grid(column=0, row=4, padx=15, pady=15)

        # Check Buttons
        self.wg_autostart = tk.Checkbutton(self, text='Autoconnect on PC Start')
        self.wg_autostart.grid(column=1, rowspan=3, row=3)
        self.wg_update = tk.Checkbutton(self, text='Search automatically for\nWire-Py updates')
        self.wg_update.grid(column=1, rowspan=3, row=4)

    def wg_switch(self):
        self.a = TunnelActiv.active()
        if self.a == '':

            self.select_tunnel = self.l_box.curselection()
            select_tl = self.l_box.get(self.select_tunnel[0])
            os.system('nmcli connection up ' + str(select_tl))
            # Button Start/Stop
            self.btn_stst = tk.Button(self, image=self.wg_vpn_stop, bd=0, command=self.wg_switch)
            self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
            self.a = TunnelActiv.active()
            self.StrVar = tk.StringVar()
            self.StrVar.set(self.a)
            self.lb_tunnel = tk.Label(self, textvariable=self.StrVar, fg='green')
            self.lb_tunnel.config(font=("Ubuntu", 11, "bold"))
            self.lb_tunnel.grid(column=3, row=1, sticky="w")
        elif self.a != '':
            # Button Start/Stop
            self.btn_stst = tk.Button(self, image=self.wg_vpn_stop, bd=0, command=self.wg_switch)
            self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
            os.system('nmcli connection down ' + str(self.a))
            # Button Start/Stop
            self.btn_stst = tk.Button(self, image=self.wg_vpn_start, bd=0, command=self.wg_switch)
            self.btn_stst.grid(column=0, row=1, padx=15, pady=15, sticky="s")
            self.a = TunnelActiv.active()
            self.StrVar = tk.StringVar()
            self.StrVar.set(value='                               ')
            self.lb_tunnel = tk.Label(self, textvariable=self.StrVar, fg='green')
            self.lb_tunnel.config(font=("Ubuntu", 11, "bold"))
            self.lb_tunnel.grid(column=3, row=1, sticky="w")


if __name__ == '__main__':
    window = MainWindow()
    window.mainloop()
